.. image:: https://i.imgur.com/GlZ6CEM.png
  :alt: Art by Ken Sugimori
  :align: center

Artiruno is a program to help you make decisions with verbal decision analysis. It's also a Python library with a class for `preordered sets`_ that should be just as useful outside the context of decision-making.

- `Try Artiruno in your web browser <http://arfer.net/projects/artiruno/webi>`_
- `Documentation <http://arfer.net/projects/artiruno/doc>`_

.. _`preordered sets`: https://en.wikipedia.org/wiki/Preorder

License
============================================================

This program is copyright 2021, 2022 Kodi B. Arfer.

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the `GNU General Public License`_ for more details.

.. _`GNU General Public License`: http://www.gnu.org/licenses/
